﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2010 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using HeuristicLab.Core.Views;
using HeuristicLab.MainForm;
using HeuristicLab.Problems.VehicleRouting.Interfaces;

namespace HeuristicLab.Problems.VehicleRouting.Views {
  [View("VRPProblemInstance View")]
  [Content(typeof(IVRPProblemInstance), true)]
  public abstract partial class VRPProblemInstanceView : ItemView {
    public new IVRPProblemInstance Content {
      get { return (IVRPProblemInstance)base.Content; }
      set { base.Content = value; }
    }

    private IVRPEncoding solution;
    public IVRPEncoding Solution {
      get {
        return solution;
      }
      set {
        solution = value;
        GenerateImage();
      }
    }

    public VRPProblemInstanceView() {
      InitializeComponent();
      Solution = null;
    }

    protected override void OnContentChanged() {
      base.OnContentChanged();
      if (Content == null) {
        pictureBox.Image = null;
      } else {
        GenerateImage();
      }
    }

    private void pictureBox_SizeChanged(object sender, EventArgs e) {
      GenerateImage();
    }

    protected abstract void DrawVisualization(Bitmap bitmap);

    private void GenerateImage() {
      if ((pictureBox.Width > 0) && (pictureBox.Height > 0)) {
        if (Content == null) {
          pictureBox.Image = null;
        } else {
          Bitmap bitmap = new Bitmap(pictureBox.Width, pictureBox.Height);

          DrawVisualization(bitmap);

          pictureBox.Image = bitmap;
        }
      }
    }
  }
}
